==> koa-ws-socket-0.1.0.tgz: package/README.md <==
<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->


- [koa-ws-socket](#koa-ws-socket)
  - [Contributors](#contributors)
  - [LICENSE](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# koa-ws-socket
Attaches [ws](https://github.com/websockets/ws) sockets to koa using koa-style middleware.

[![Build Status][build-badge]][build]
[![Code Coverage][coverage-badge]][coverage]
[![version][version-badge]][package]
[![downloads][downloads-badge]][npmcharts]
[![MIT License][license-badge]][LICENSE]

[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors)
[![PRs Welcome][prs-badge]][prs]
[![Code of Conduct][coc-badge]][coc]

## Contributors

Thanks goes to these people ([emoji key][emojis]):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
| [<img src="https://avatars0.githubusercontent.com/u/1402095?v=4" width="100px;"/><br /><sub>Matt Parrish</sub>](https://github.com/pbomb)<br />[💻](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Code") [📖](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Documentation") [⚠️](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Tests") [👀](#review-pbomb "Reviewed Pull Requests") |
| :---: |
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors][all-contributors] specification.
Contributions of any kind welcome!

## LICENSE

MIT

[build-badge]: https://img.shields.io/travis/pbomb/koa-ws-socket.svg?style=flat-square
[build]: https://travis-ci.org/pbomb/koa-ws-socket
[coverage-badge]: https://img.shields.io/codecov/c/github/pbomb/koa-ws-socket.svg?style=flat-square
[coverage]: https://codecov.io/github/pbomb/koa-ws-socket
[version-badge]: https://img.shields.io/npm/v/koa-ws-socket.svg?style=flat-square
[package]: https://www.npmjs.com/package/koa-ws-socket
[downloads-badge]: https://img.shields.io/npm/dm/koa-ws-socket.svg?style=flat-square
[npmcharts]: https://npmcharts.com/compare/koa-ws-socket
[license-badge]: https://img.shields.io/npm/l/koa-ws-socket.svg?style=flat-square
[license]: https://github.com/pbomb/koa-ws-socket/blob/master/LICENSE
[prs-badge]: https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square
[prs]: http://makeapullrequest.com
[chat]: https://gitter.im/pbomb/koa-ws-socket
[chat-badge]: https://img.shields.io/gitter/room/pbomb/koa-ws-socket.svg?style=flat-square
[coc-badge]: https://img.shields.io/badge/code%20of-conduct-ff69b4.svg?style=flat-square
[coc]: https://github.com/pbomb/koa-ws-socket/blob/master/other/CODE_OF_CONDUCT.md
[github-watch-badge]: https://img.shields.io/github/watchers/pbomb/koa-ws-socket.svg?style=social
[github-watch]: https://github.com/pbomb/koa-ws-socket/watchers
[github-star-badge]: https://img.shields.io/github/stars/pbomb/koa-ws-socket.svg?style=social
[github-star]: https://github.com/pbomb/koa-ws-socket/stargazers
[emojis]: https://github.com/kentcdodds/all-contributors#emoji-key
[all-contributors]: https://github.com/kentcdodds/all-contributors

==> koa-ws-socket-3.0.1.tgz: package/README.md <==
<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->


- [koa-ws-socket](#koa-ws-socket)
  - [Contributors](#contributors)
  - [LICENSE](#license)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

# koa-ws-socket
Attaches [ws](https://github.com/websockets/ws) sockets to koa using koa-style middleware.

[![Build Status][build-badge]][build]
[![Code Coverage][coverage-badge]][coverage]
[![version][version-badge]][package]
[![downloads][downloads-badge]][npmcharts]
[![MIT License][license-badge]][LICENSE]

[![All Contributors](https://img.shields.io/badge/all_contributors-2-orange.svg?style=flat-square)](#contributors)
[![PRs Welcome][prs-badge]][prs]
[![Code of Conduct][coc-badge]][coc]

## Contributors

Thanks goes to these people ([emoji key][emojis]):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
| [<img src="https://avatars0.githubusercontent.com/u/1402095?v=4" width="100px;"/><br /><sub>Matt Parrish</sub>](https://github.com/pbomb)<br />[💻](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Code") [📖](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Documentation") [⚠️](https://github.com/pbomb/koa-ws-socket/commits?author=pbomb "Tests") [👀](#review-pbomb "Reviewed Pull Requests") | [<img src="https://avatars3.githubusercontent.com/u/1319157?v=4" width="100px;"/><br /><sub>mateuscb</sub>](https://github.com/mateuscb)<br />[💻](https://github.com/pbomb/koa-ws-socket/commits?author=mateuscb "Code") [⚠️](https://github.com/pbomb/koa-ws-socket/commits?author=mateuscb "Tests") |
| :---: | :---: |
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors][all-contributors] specification.
Contributions of any kind welcome!

## LICENSE

MIT

[build-badge]: https://img.shields.io/travis/pbomb/koa-ws-socket.svg?style=flat-square
[build]: https://travis-ci.org/pbomb/koa-ws-socket
[coverage-badge]: https://img.shields.io/codecov/c/github/pbomb/koa-ws-socket.svg?style=flat-square
[coverage]: https://codecov.io/github/pbomb/koa-ws-socket
[version-badge]: https://img.shields.io/npm/v/koa-ws-socket.svg?style=flat-square
[package]: https://www.npmjs.com/package/koa-ws-socket
[downloads-badge]: https://img.shields.io/npm/dm/koa-ws-socket.svg?style=flat-square
[npmcharts]: https://npmcharts.com/compare/koa-ws-socket
[license-badge]: https://img.shields.io/npm/l/koa-ws-socket.svg?style=flat-square
[license]: https://github.com/pbomb/koa-ws-socket/blob/master/LICENSE
[prs-badge]: https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square
[prs]: http://makeapullrequest.com
[chat]: https://gitter.im/pbomb/koa-ws-socket
[chat-badge]: https://img.shields.io/gitter/room/pbomb/koa-ws-socket.svg?style=flat-square
[coc-badge]: https://img.shields.io/badge/code%20of-conduct-ff69b4.svg?style=flat-square
[coc]: https://github.com/pbomb/koa-ws-socket/blob/master/other/CODE_OF_CONDUCT.md
[github-watch-badge]: https://img.shields.io/github/watchers/pbomb/koa-ws-socket.svg?style=social
[github-watch]: https://github.com/pbomb/koa-ws-socket/watchers
[github-star-badge]: https://img.shields.io/github/stars/pbomb/koa-ws-socket.svg?style=social
[github-star]: https://github.com/pbomb/koa-ws-socket/stargazers
[emojis]: https://github.com/kentcdodds/all-contributors#emoji-key
[all-contributors]: https://github.com/kentcdodds/all-contributors
